@@ -3,15 +3,16 @@
 """
 
 from dataclasses import dataclass
-from typing import Optional
+from typing import List, Optional
 
 from pyfacebook.models.base import BaseModel, field
+from pyfacebook.models.extensions import Paging
 
 
 @dataclass
-class ProfilePicture(BaseModel):
+class ProfilePictureSource(BaseModel):
     """
-    A class representing Profile Picture
+    A class representing Profile Picture Source
 
     Refer: https://developers.facebook.com/docs/graph-api/reference/profile-picture-source/
     """
@@ -23,6 +24,18 @@ class ProfilePicture(BaseModel):
     width: Optional[int] = field()
 
 
+@dataclass
+class Picture(BaseModel):
+    """
+    A class representing the Picture connection.
+
+    Refer: https://developers.facebook.com/docs/graph-api/reference/page/picture
+    """
+
+    data: Optional[ProfilePictureSource] = field(repr=True)
+    paging: Optional[Paging] = field()
+
+
 @dataclass
 class CoverPhoto(BaseModel):
     """
@@ -35,3 +48,14 @@ class CoverPhoto(BaseModel):
     offset_x: Optional[float] = field()
     offset_y: Optional[float] = field()
     source: Optional[str] = field(repr=True)
+
+
+@dataclass
+class ImageSource(BaseModel):
+    """
+    A class representing the Image Source.
+    """
+
+    height: Optional[int] = field()
+    width: Optional[int] = field()
+    src: Optional[str] = field(repr=True)
